package com.xqopen.kehui;

import com.xqopen.kehui.interceptor.Permission;
import com.xqopen.kehui.interceptor.RequiresPermissions;
import lombok.extern.slf4j.Slf4j;

import java.lang.reflect.Field;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * api列表
 */
@Slf4j
public class Api {


    public static Map<String, Permission> permissionList = new ConcurrentHashMap<>();

    static {
        try {
            Api instance = new Api();
            Class<Api> clazz = Api.class;
            Field[] fields = clazz.getFields();
            for (Field i : fields) {
                RequiresPermissions a = i.getAnnotation(RequiresPermissions.class);
                if (a != null) {
                    String url = i.get(instance).toString();
                    Permission perm = new Permission();
                    perm.setDescription(a.description());
                    perm.setValue(a.value());
                    perm.setUrl(url);
                    permissionList.put(url, perm);
                }
            }
        } catch (Exception e) {
            log.error("init api error", e);
        }
    }

    public static Permission getItem(String url) {
        return permissionList.get(url);
    }


    private Api() {
    }

    public static void main(String[] args) {
        System.out.println(permissionList);
    }

    public static final String ROOT = "/";

    public static final String SWAGGER = "/swagger";

    public static final String PREFIX = "/api";

    public static final String HELLO = PREFIX + "/hello";

    public static final String DB_TEST = PREFIX + "/db-test";

    public static final String PERMISSION_TEST = PREFIX + "/perm";

    public static final String GET_VERSION = PREFIX + "/get-version";

    public static final String TEST_EMAIL = PREFIX + "/test-email";

    //登录
    public static final String LOGIN = PREFIX + "/login";

    public static final String GET_USER_PERMISSIONS = PREFIX + "/user-permissions";

    public static final String SYSTEM = PREFIX + "/system";

    //数据角色
    public static final String SYSTEMROLE = SYSTEM + "/role";

    public static final String ADD_SYSTEMROLE = SYSTEMROLE;

    public static final String EDIT_SYSTEMROLE = SYSTEMROLE + "/{id}";

    public static final String DEL_SYSTEMROLE = SYSTEMROLE + "/{id}";

    public static final String BATCHDEL_SYSTEMROLE = SYSTEMROLE;

    public static final String LIST_SYSTEMROLE = SYSTEMROLE;

    public static final String GET_SYSTEMROE = SYSTEMROLE + "/{id}";

    public static final String GET_SYSTEMROLE_BYORGID = SYSTEMROLE + "/{id}/leader";

    public static final String SYSTEM_ROLE_WEIGHTS = SYSTEM + "/role_weights";

    public static final String ADD_SYSTEM_ROLE_WEIGHTS = SYSTEM_ROLE_WEIGHTS;

    public static final String EDIT_SYSTEM_ROLE_WEIGHTS = SYSTEM_ROLE_WEIGHTS + "/{id}";

    public static final String DEL_SYSTEM_ROLE_WEIGHTS = SYSTEM_ROLE_WEIGHTS;

    public static final String LIST_SYSTEM_ROLE_WEIGHTS = SYSTEM_ROLE_WEIGHTS;


    //菜单管理
    private static final String MENU_PREFIX = SYSTEM + "/menu";

    public static final String ADD_SYSTEM_MENU = MENU_PREFIX;

    public static final String EDIT_SYSTEM_MENU = MENU_PREFIX + "/{id}";

    public static final String LIST_SYSTEM_MENU = MENU_PREFIX;

    public static final String DEL_SYSTEM_MENU = MENU_PREFIX;

    /**
     * 短信统计管理
     */
    public static final String GET_SYSTEM_SMS_RECORD = SYSTEM + "/sms";


    /**
     * 内容管理
     */

    @RequiresPermissions(value = "a:query", description = "查询xxx")
    public static final String COMMON_PREFIX = PREFIX + "/common";

    public static final String CONTENTS_PREFIX = COMMON_PREFIX + "/contents";

    public static final String ADD_CONTENTS = CONTENTS_PREFIX;

    public static final String FIND_CONTENTS = CONTENTS_PREFIX + "-find";

    public static final String DEL_CONTENTS_VALUE = CONTENTS_PREFIX;

    public static final String EDIT_CONTENTS_VALUE = CONTENTS_PREFIX + "/{id}";

    public static final String COMMON_UPLOAD = COMMON_PREFIX + "/file-upload";

    public static final String SETREADER_CONTENTS_NOTICE = CONTENTS_PREFIX + "/setreader//{id}";

    //所长添加批注
    public static final String ADD_ADMINIMEETING_ANNOTATION = COMMON_PREFIX + "/annotation/{id}";

    /**
     * 账号管理
     */
    private static final String USERLOGIN_PREFIX = SYSTEM + "/user-login";

    public static final String ADD_USERLOGIN = USERLOGIN_PREFIX + "/temporary";

    public static final String EDIT_USERLOGIN = USERLOGIN_PREFIX + "/{id}";

    public static final String DEL_USERLOGIN = USERLOGIN_PREFIX + "/{id}";

    public static final String BATCHDEL_USERLOGIN = USERLOGIN_PREFIX;

    public static final String GET_USERLOGIN = USERLOGIN_PREFIX + "/{id}";

    public static final String LIST_USERLOGIN = USERLOGIN_PREFIX;

    /**
     * 角色权限管理
     */
    private static final String USERROLE_PREFIX = SYSTEM + "/user-roles";

    public static final String ADD_USERROLE = USERROLE_PREFIX;

    public static final String LIST_USERROLE = USERROLE_PREFIX;

    public static final String EDIT_USERROLE = USERROLE_PREFIX;

    public static final String DEL_USERROLE = USERROLE_PREFIX + "/{id}";

    public static final String BATCHDEL_USERROLE = USERROLE_PREFIX;

    /**
     * 基础资料设置
     */

    public static final String TERM = COMMON_PREFIX + "/terms";

    public static final String LIST_TERM = TERM + "-list";

    public static final String LIST_TERM_BY_BIG = TERM + "-listByItemBig";

    public static final String LIST_TERM_BY_CLASSIFY_ID = TERM + "-listByClassifyId";

    public static final String ADD_TERM = TERM;

    public static final String FIND_TERM = TERM + "-find";

    public static final String DEL_TERM_VALUE = TERM;

    public static final String EDIT_TERM_VALUE = TERM + "/{id}";

    /**
     * 年休假
     */
    public static final String ANNUAL_LEAVE = COMMON_PREFIX + "/annual-leave";

    public static final String SYSTEM_ANNUAL_LEAVE_EDIT = ANNUAL_LEAVE + "/{id}";

    public static final String SYSTEM_ANNUAL_LEAVE_GET_PERSONID = ANNUAL_LEAVE + "/{id}/person";

    public static final String SYSTEM_ANNUAL_LEAVE_GETPERSON = ANNUAL_LEAVE + "/persons";

    /**
     * 流程设置
     */
    private static final String FLOWCONFIGURATION = COMMON_PREFIX + "/flowconfiguration";

    public static final String ADD_FLOWCONFIGURATION = FLOWCONFIGURATION;

    public static final String EDIT_FLOWCONFIGURATION = FLOWCONFIGURATION + "/edit/{id}";

    public static final String DEL_FLOWCONFIGURATION = FLOWCONFIGURATION + "/delete/{id}";

    public static final String LIST_FLOWCONFIGURATION = FLOWCONFIGURATION;


    /**
     * 组织架构
     */

    public static final String SYSTEM_ORG = COMMON_PREFIX + "/orgs";

    public static final String ADD_SYSTEM_ORG = SYSTEM_ORG;

    public static final String FIND_SYSTEM_ORG = SYSTEM_ORG;

    public static final String GET_SYSTEM_ORG = SYSTEM_ORG + "/{id}";

    public static final String GET_SYSTEM_ORG_NAME = SYSTEM_ORG + "/getName";
    public static final String DEL_SYSTEM_ORG_VALUE = SYSTEM_ORG;

    public static final String EDIT_SYSTEM_ORG_VALUE = SYSTEM_ORG + "/{id}";

    /**
     * 通知
     */
    public static final String SYSTEM_SMS = COMMON_PREFIX + "/sms";

    public static final String SEND_SMS = SYSTEM_SMS;

    /**
     * 表单管理（内部使用）
     */
    public static final String SYSTEM_SCHEMA = COMMON_PREFIX + "/schemas";

    public static final String GET_SCHEMA = SYSTEM_SCHEMA + "/{schemaName}";


    /**
     * 后勤管理
     */

    public static final String LOGISTICS_PREFIX = PREFIX + "/logistics";

    /**
     * 接待管理
     */

    public static final String LOGISTICS_VISITOR_BEFORE = LOGISTICS_PREFIX + "/visitor-before";

    public static final String LOGISTICS_VISITOR_BEFORE_GET = LOGISTICS_VISITOR_BEFORE + "/{id}";

    /**
     * 公务出差管理
     */
    public static final String LOGISTICS_BUSINESS_TRIP = LOGISTICS_PREFIX + "/business-trips";

    public static final String LOGISTICS_BUSINESS_TRIP_GET = LOGISTICS_BUSINESS_TRIP + "/{id}";

    /**
     * 公务出差管理
     */
    public static final String LOGISTICS_USE_CAR = LOGISTICS_PREFIX + "/use-car";

    public static final String LOGISTICS_USE_CAR_FIND = LOGISTICS_USE_CAR + "-find";

    public static final String LOGISTICS_USE_CAR_GET = LOGISTICS_USE_CAR + "/{id}";


    /**
     * 大型会议管理
     */

    public static final String LOGISTICS_MEETING = LOGISTICS_PREFIX + "/meetings";

    public static final String LOGISTICS_MEETING_GET = LOGISTICS_MEETING + "/{id}";

    /**
     * 资产管理
     */
    public static final String LOGISTICS_ASSETS = LOGISTICS_PREFIX + "/assets";

    public static final String LOGISTICS_ADD_ASSETS = LOGISTICS_ASSETS;

    public static final String LOGISTICS_FIND_ASSETS = LOGISTICS_ASSETS + "-find";

    public static final String LOGISTICS_ASSETS_EDIT = LOGISTICS_ASSETS + "/{id}";

    /**
     * 领用管理
     */
    public static final String LOGISTICS_ASSETS_RECEIVE = LOGISTICS_PREFIX + "/assets-receive";

    public static final String LOGISTICS_ASSETS_RECEIVE_FIND = LOGISTICS_PREFIX + "/assets-receive-find";

    public static final String LOGISTICS_ASSETS_RECEIVE_EDIT = LOGISTICS_ASSETS_RECEIVE + "/{id}";

    public static final String LOGISTICS_ASSETS_RECEIVE_GET = LOGISTICS_ASSETS_RECEIVE + "/{id}";

    public static final String LOGISTICS_ASSETS_RECEIVE_EXPORT = LOGISTICS_PREFIX + "/assets/receive/export";

    /**
     * 库存管理
     */
    public static final String LOGISTICS_INVENTORY_MANAGEMENT = LOGISTICS_PREFIX + "/inventory-management";


    public static final String LOGISTICS_INVENTORY_MANAGEMENT_LIST = LOGISTICS_INVENTORY_MANAGEMENT;

    public static final String LOGISTICS_INVENTORY_MANAGEMENT_GET = LOGISTICS_INVENTORY_MANAGEMENT + "/{id}";

    public static final String LOGISTICS_INVENTORY_MANAGEMENT_DEL = LOGISTICS_INVENTORY_MANAGEMENT + "/{id}";

    public static final String LOGISTICS_INVENTORY_MANAGEMENT_EDIT = LOGISTICS_INVENTORY_MANAGEMENT + "/{id}";


    public static final String LOGISTICS_INVENTORY_MANAGEMENT_IMPORT = LOGISTICS_INVENTORY_MANAGEMENT + "/import";


    /**
     * 采购申请管理
     */
    public static final String LOGISTICS_PURCHASE = LOGISTICS_PREFIX + "/purchases";

    public static final String LOGISTICS_ADD_PURCHASE = LOGISTICS_PURCHASE;

    public static final String LOGISTICS_FIND_PURCHASE = LOGISTICS_PURCHASE + "-find";

    public static final String LOGISTICS_PURCHASE_EDIT = LOGISTICS_PURCHASE + "/{id}";


    /**
     * 项目管理
     */
    public static final String PROJECT_PREFIX = PREFIX + "/project";

    /**
     * 项目信息管理
     */
    public static final String PROJECT_INFO = PROJECT_PREFIX + "/infos";
    public static final String PROJECT_INIT = PROJECT_PREFIX + "/inits";

    public static final String PROJECT_INFO_GET = PROJECT_INFO + "/{id}";

    public static final String PROJECT_INFO_EDIT = PROJECT_INFO + "/{id}";
    public static final String PROJECT_INIT_LIST= PROJECT_INIT+"/list";
    public static final String PROJECT_INIT_EDIT= PROJECT_INIT+"/{id}";
    public static final String PROJECT_INFO_ADD = PROJECT_INFO;
    public static final String PROJECT_INIT_ADD = PROJECT_INIT+"/add";

    public static final String PROJECT_INFO_LIST = PROJECT_INFO + "/projects";

    public static final String PROJECT_INFO_GETPROJECTS = PROJECT_INFO;

    public static final String PROJECT_INFO_GET_ACCEPT_PROJECTS = PROJECT_INFO + "/accept";

    public static final String PROJECT_INFO_MODEL = PROJECT_INFO + "/model";

    public static final String PROJECT_INFO_START = PROJECT_INFO + "/{id}" + "/start";

    /**
     * 成果申请管理
     */
    public static final String PROJECT_ACHIEVEMENTS = PROJECT_PREFIX + "/achievements";

    public static final String ADD_PROJECT_ACHIEVEMENTS = PROJECT_ACHIEVEMENTS;

    public static final String GET_PROJECT_ACHIEVEMENTS = PROJECT_ACHIEVEMENTS + "/{id}";

    public static final String DEL_PROJECT_ACHIEVEMENTS = PROJECT_ACHIEVEMENTS;

    public static final String LIST_PROJECT_ACHIEVEMENTS = PROJECT_ACHIEVEMENTS + "-list";

    public static final String LIST_PROJECT_PERSONAL_ACHIEVEMENTS = PROJECT_ACHIEVEMENTS + "/list/personal";

    public static final String ADD_TABLE_PROJECT_ACHIEVEMENTS = PROJECT_ACHIEVEMENTS + "-add" + "/{id}";

    public static final String EDIT_PROJECT_ACHIEVEMENTS = PROJECT_ACHIEVEMENTS + "/{id}";


    /**
     * 人事管理
     */
    public static final String PERSONAL_PREFIX = PREFIX + "/personal";

    /**
     * 人员信息管理
     */
    public static final String PERSONAL_USER_INFO = PERSONAL_PREFIX + "/user-infos";

    public static final String PERSONAL_USER_INFO_FIND = PERSONAL_USER_INFO + "-find";

    public static final String PERSONAL_USER_INFO_LIST_BY_DEPT = PERSONAL_USER_INFO + "-list";

    public static final String PERSONAL_USER_INFO_LIST_WITH_PARTY = PERSONAL_USER_INFO_LIST_BY_DEPT + "-party";

    public static final String PERSONAL_USER_INFO_EDIT = PERSONAL_USER_INFO + "/{id}";

    /**
     * 人员信息管理-新
     */
    public static final String PERSONAL_MEMBER = PERSONAL_PREFIX + "/members";

    public static final String PERSONAL_MEMBER_LIST = PERSONAL_MEMBER + "/list";

    public static final String PERSONAL_MEMBER_GET = PERSONAL_MEMBER + "/{id}";

    public static final String PERSONAL_MEMBER_EDIT = PERSONAL_MEMBER + "/{id}";

    public static final String PERSONAL_MEMBER_DEL = PERSONAL_MEMBER + "/{id}";

    public static final String PERSONAL_MEMBER_LIST_BY_DEPT = PERSONAL_MEMBER + "/list/dept";

    public static final String PERSONAL_LEADERMEMBER_BY_DEPT = PERSONAL_MEMBER + "/leader";

    public static final String PERSONAL_MEMBER_BY_PERSONAME = PERSONAL_MEMBER + "/byName";

    public static final String PERSONAL_MEMBER_LIKE_ROLETAG = PERSONAL_MEMBER + "/list/roletag";

    public static final String PERSONAL_MEMBER_APPROVED = PERSONAL_MEMBER + "/approved/{id}";


    /**
     * 工资管理
     */
    public static final String PERSONAL_WAGE = PERSONAL_PREFIX + "/wages";

    public static final String PERSONAL_USER_INFO_GET = PERSONAL_USER_INFO + "/{id}";

    public static final String PERSONAL_USER_INFO_EDITTEMP = PERSONAL_USER_INFO + "/{id}" + "/temp";

    public static final String PERSONAL_USER_INFO_APPROVED = PERSONAL_USER_INFO + "-approved/{id}";

    public static final String PERSONAL_WAGE_FIND = PERSONAL_WAGE + "-find";

    public static final String PERSONAL_WAGE_EDIT = PERSONAL_WAGE + "/{id}";

    /**
     * 职位管理
     */
    public static final String PERSONAL_JOB = PERSONAL_PREFIX + "/jobs";

    public static final String PERSONAL_JOB_FIND = PERSONAL_JOB + "-find";

    /**
     * 合同管理
     */
    public static final String PERSONAL_CONTRACT = PERSONAL_PREFIX + "/contracts";

    public static final String PERSONAL_CONTRACT_FIND = PERSONAL_CONTRACT + "-find";

    public static final String PERSONAL_CONTRACT_EDIT = PERSONAL_CONTRACT + "/{id}";

    /**
     * 绩效管理
     */
    public static final String PERSONAL_PERFORMANCE = PERSONAL_PREFIX + "/performances";

    public static final String PERSONAL_PERFORMANCE_FIND = PERSONAL_PERFORMANCE + "-find";

    public static final String PERSONAL_PERFORMANCE_EDIT = PERSONAL_PERFORMANCE + "/{id}";

    public static final String PERSONAL_PERFORMANCE_SCORE = PERSONAL_PREFIX + "/performances-score";

    public static final String ADD_PERSONAL_PERFORMANCE_SCORE = PERSONAL_PERFORMANCE_SCORE;

    public static final String GET_PERSON_PERSONAL_PERFORMANCE_SCORE = PERSONAL_PERFORMANCE_SCORE + "/persons";

    public static final String GET_PERSONAL_PERFORMANCE_SCORE = PERSONAL_PERFORMANCE_SCORE + "/{id}";

    public static final String EDIT_PERSONAL_PERFORMANCE_SCORE = PERSONAL_PERFORMANCE_SCORE + "/{id}";

    public static final String DEL_PERSONAL_PERFORMANCE_SCORE = PERSONAL_PERFORMANCE_SCORE;

    public static final String LIST_PERSONAL_PERFORMANCE_SCORE = PERSONAL_PERFORMANCE_SCORE + "/person-list";

    public static final String SINGLE_PERSONAL_PERFORMANCE_SCORE = PERSONAL_PERFORMANCE_SCORE + "/single";


    /**
     * 人员事件管理
     */
    public static final String PERSONAL_EVENTS = PERSONAL_PREFIX + "/events";

    public static final String ADD_PERSONAL_EVENTS = PERSONAL_EVENTS;

    public static final String EDIT_PERSONAL_EVENTS = PERSONAL_EVENTS + "/{id}";

    public static final String EDIT_PERSONAL_SALESLEAVE = PERSONAL_EVENTS + "/leave/sales/{id}";

    public static final String EDIT_PERSONAL_DELAYLEAVE = PERSONAL_EVENTS + "/leave/delay/{id}";

    public static final String GET_PERSONAL_EVENTS = PERSONAL_EVENTS + "/{id}";

    public static final String LIST_PERSONAL_EVENTS = PERSONAL_EVENTS + "/events-list";

    /**
     * 绩效系数
     */
    public static final String PERSONAL_PERFORMANCE_COEFFICIENT_PREFIX = PERSONAL_PREFIX + "/performances-coefficient";

    public static final String ADD_PERSONAL_PERFORMANCE_COEFFICIENT = PERSONAL_PERFORMANCE_COEFFICIENT_PREFIX;

    public static final String EDIT_PERSONAL_PERFORMANCE_COEFFICIENT = PERSONAL_PERFORMANCE_COEFFICIENT_PREFIX + "/{id}";

    public static final String DEL_PERSONAL_PERFORMANCE_COEFFICIENT = PERSONAL_PERFORMANCE_COEFFICIENT_PREFIX;

    public static final String LIST_PERSONAL_PERFORMANCE_COEFFICIENT = PERSONAL_PERFORMANCE_COEFFICIENT_PREFIX;

    public static final String GET_PERSONAL_PERFORMANCE_COEFFICIENT = PERSONAL_PERFORMANCE_COEFFICIENT_PREFIX + "/{id}";

    /**
     * 薪酬
     */
    public static final String PERSONAL_SALARY_PREFIX = PERSONAL_PREFIX + "/salary";

    public static final String BUILD_PERSONAL_SALARY = PERSONAL_PREFIX + "/persons";

    public static final String GET_PERSONAL_SALARY = PERSONAL_SALARY_PREFIX + "/{id}";

    public static final String ADD_PERSONAL_SALARY = PERSONAL_SALARY_PREFIX;

    public static final String EDIT_PERSONAL_SALARY = PERSONAL_SALARY_PREFIX + "/{id}";

    public static final String DEL_PERSONAL_SALARY = PERSONAL_SALARY_PREFIX;

    public static final String LIST_PERSONAL_SALARY = PERSONAL_SALARY_PREFIX;

    public static final String SINGLE_PERSONAL_SALARY = PERSONAL_SALARY_PREFIX + "/single";


    /**
     * 系统日志
     */
    public static final String SYSTEMLOG = PREFIX + "/system/logs";

    public static final String ADD_SYSTEM_LOG = SYSTEMLOG;

    public static final String DEL_SYSTEMLOG = SYSTEMLOG + "/{id}";

    public static final String BATCHDEL_SYSTEMLOG = SYSTEMLOG;

    public static final String LIST_SYSTEMLOG = SYSTEMLOG;


    /**
     * 流程审批
     */
    private static final String ACTIVITI_PREFIX = "/flows";

    public static final String DEPLOY_ACTIVITI = ACTIVITI_PREFIX;

    public static final String DEPLOY_ACTIVITI_A = ACTIVITI_PREFIX + "/list";

    public static final String START_ACTIVITI = ACTIVITI_PREFIX + "/start";

    public static final String COMMIT_ACTIVITI = ACTIVITI_PREFIX + "/commit";

    public static final String BACK_ACTIVITI = ACTIVITI_PREFIX + "/back";

    public static final String END_ACTIVITI = ACTIVITI_PREFIX + "/end";

    public static final String LIST_ACTIVITI = ACTIVITI_PREFIX;

    public static final String RECEIVE_ACTIVITI = ACTIVITI_PREFIX + "/receive";

    public static final String GET_ACTIVITI_BY_TASKID = ACTIVITI_PREFIX + "/activiti";


    public static final String STATUS_ACTIVITI = ACTIVITI_PREFIX + "/status";

    public static final String RECORDS_ACTIVITI = ACTIVITI_PREFIX + "/records" + "/{id}";

    public static final String COUNT_ACTIVITI = ACTIVITI_PREFIX + "/count";

    public static final String COUNT_ACTIVITI_CHECK = ACTIVITI_PREFIX + "/countCheck";

    public static final String PRINT_ACTIVITI = ACTIVITI_PREFIX + "/print";

    public static final String GET_CATEGORY_BY_TYPE = ACTIVITI_PREFIX + "/search/category";

    /**
     * 会议室管理
     */


    public static final String ADMINISTRATION = PREFIX + "/administration";

    private static final String ADMINIMEETINGMANAGEMENT = ADMINISTRATION + "/meeting-manage";

    public static final String ADD_ADMINIMEETINGMANAGEMENT = ADMINIMEETINGMANAGEMENT;

    public static final String EDIT_ADMINIMEETINGMANAGEMENT = ADMINIMEETINGMANAGEMENT + "/{id}";

    public static final String DEL_ADMINIMEETINGMANAGEMENT = ADMINIMEETINGMANAGEMENT + "/{id}";

    public static final String BATCHDEL_ADMINIMEETINGMANAGEMENT = ADMINIMEETINGMANAGEMENT;

    public static final String LIST_ADMINIMEETINGMANAGEMENT = ADMINIMEETINGMANAGEMENT;

    public static final String UNUSED_ADMINMEETINGMANAGEMENT = ADMINIMEETINGMANAGEMENT;

    public static final String GET_ADMINIMEETINGMANAGEMENT = ADMINIMEETINGMANAGEMENT;


    /**
     * 会议室申请管理
     */
    private static final String ADMIN_MEETING_APPLY = ADMINISTRATION + "/meeting-apply";

    public static final String ADD_ADMIN_MEETING_APPLY = ADMIN_MEETING_APPLY;

    public static final String GET_ADMIN_MEETING_APPLY = ADMIN_MEETING_APPLY + "/{id}";

    public static final String EDIT_ADMIN_MEETING_APPLY = ADMIN_MEETING_APPLY + "/{id}";

    public static final String DEL_ADMIN_MEETING_APPLY = ADMIN_MEETING_APPLY;

    public static final String LIST_ADMIN_MEETING_APPLY = ADMIN_MEETING_APPLY;


    /**
     * 公文管理
     */
    private static final String ADMIN_DOCUMENT_MANAGEMENT_PREFIX = ADMINISTRATION + "/document-manage";

    public static final String GET_ADMIN_DOCUMENT_MANAGEMENT = ADMIN_DOCUMENT_MANAGEMENT_PREFIX + "/{id}";

    public static final String GET_ADMIN_DOCUMENT_MANAGEMENT_NUMBER = ADMIN_DOCUMENT_MANAGEMENT_PREFIX + "/number/{id}";

    public static final String ADD_ADMIN_DOCUMENT_MANAGEMENT = ADMIN_DOCUMENT_MANAGEMENT_PREFIX;

    public static final String EDIT_ADMIN_DOCUMENT_MANAGEMENT = ADMIN_DOCUMENT_MANAGEMENT_PREFIX + "/{id}";

    public static final String DEL_ADMIN_DOCUMENT_MANAGEMENT = ADMIN_DOCUMENT_MANAGEMENT_PREFIX;

    public static final String LIST_ADMIN_DOCUMENT_MANAGEMENT = ADMIN_DOCUMENT_MANAGEMENT_PREFIX + "/documents";

    public static final String LIST_ADMIN_DOCUMENT_MANAGEMENT_NOTICE = ADMIN_DOCUMENT_MANAGEMENT_PREFIX + "/documentsNotice";

    public static final String SETREADER_ADMIN_DOCUMENT = ADMIN_DOCUMENT_MANAGEMENT_PREFIX + "/setreader/{id}";

    public static final String GETNOTREADER_COUNT = ADMIN_DOCUMENT_MANAGEMENT_PREFIX + "/notread";
    public static final String GETRECNOTREADER_COUNT = ADMIN_DOCUMENT_MANAGEMENT_PREFIX + "/recnotread";

    public static final String UPLOAD_FILE_ADMIN_DOCUMENT_MANAGEMENT = ADMIN_DOCUMENT_MANAGEMENT_PREFIX + "/upload/{id}";

    /*开票管理*/
    private static final String ADMIN_INVOICE_MANAGEMENT_PREFIX = ADMINISTRATION + "/invoice-manage";

    private static final String ADMIN_INVOICE_MANAGEMENT_PREFIX_STATUS = ADMINISTRATION + "/invoice-manage-status";

    public static final String ADD_ADMIN_INVOICE_MANAGEMENT = ADMIN_INVOICE_MANAGEMENT_PREFIX;

    public static final String LIST_ADMIN_INVOIVE_MANAGEMENT = ADMIN_INVOICE_MANAGEMENT_PREFIX + "/invoice";

    public static final String GET_ADMIN_INVOICE_MANAGEMENT = ADMIN_INVOICE_MANAGEMENT_PREFIX + "/{id}";

    public static final String EDIT_ADMIN_INVOICE_MANAGEMENT = ADMIN_INVOICE_MANAGEMENT_PREFIX + "/{id}";

    public static final String EDIT_ADMIN_INVOICE_MANAGEMENT_STATUS = ADMIN_INVOICE_MANAGEMENT_PREFIX_STATUS + "/{id}";





    /**
     * 印章管理
     */
    public static final String ADMIN_SEAL_MANAGEMENT = ADMINISTRATION + "/seals";

    public static final String ADMIN_SEAL_MANAGEMENT_GET = ADMIN_SEAL_MANAGEMENT + "/{id}";

    public static final String EDIT_ADMIN_SEAL = ADMIN_SEAL_MANAGEMENT + "-borrow" + "/edit";

    public static final String GET_SEAL_TYPE = ADMIN_SEAL_MANAGEMENT + "/seals-type";

    public static final String GET_PEERS_BY_DEPTID = ADMIN_SEAL_MANAGEMENT + "/get-peers/{id}";

    public static final String ADMIN_SEAL_MANAGEMENT_COVER = ADMIN_SEAL_MANAGEMENT + "-cover";

    public static final String ADMIN_SEAL_MANAGEMENT_BORROW = ADMIN_SEAL_MANAGEMENT + "-brroow";

    public static final String ADMIN_SEAL_AVAILABLESEAL_GET = ADMIN_SEAL_MANAGEMENT + "-availableSeal";

    public static final String ADMIN_SEAL_TYPE = ADMIN_SEAL_MANAGEMENT + "-type";

    /**
     * 任务管理
     **/
    public static final String ADMIN_TASK_MANAGEMENT = ADMINISTRATION + "/task";

    public static final String LIST_ADMIN_TASK = ADMIN_TASK_MANAGEMENT + "/list";

    public static final String GET_ADMIN_TASK = ADMIN_TASK_MANAGEMENT + "/{id}";

    public static final String EDIT_ADMIN_TASK = ADMIN_TASK_MANAGEMENT + "/{id}";

    public static final String ADD_ADMIN_TASK = ADMIN_TASK_MANAGEMENT;

    public static final String EDIT_ADMIN_TASK_PROPESS = ADMIN_TASK_MANAGEMENT + "-editProcess" + "/{id}";

    public static final String ADD_ADMIN_JOB_TASK = ADMIN_TASK_MANAGEMENT + "/job-task";

    public static final String ADD_QUARTERLY_PLAN_TASK = ADMIN_TASK_MANAGEMENT + "/add-quarterly"; //	添加季度任务

    public static final String EDIT_QUARTERLY_PLAN_TASK = ADMIN_TASK_MANAGEMENT + "/edit-quarterly" + "/{id}"; //	修改季度任务

    public static final String DOWN_QUARTERLY_PLAN_TASK = ADMIN_TASK_MANAGEMENT + "/down-quarterly" + "/{id}"; //	完成季度任务

    public static final String COMMENT_QUARTERLY_PLAN_TASK = ADMIN_TASK_MANAGEMENT + "/comment-quarterly" + "/{id}"; //	所长评论季度任务

    public static final String QUARTERLY_PLAN_TASK_LIST = ADMIN_TASK_MANAGEMENT + "/list/quarterly"; //获取季度计划任务列表

    public static final String QUARTERLY_PLAN_TASK_LIST_DETAIL = ADMIN_TASK_MANAGEMENT + "/list/quarterly/detail"; //获取季度计划任务详情列表

    public static final String ADMIN_TASK_MANAGEMENT_PLAN = ADMIN_TASK_MANAGEMENT + "/quarter" + "/{id}"; //获取季度计划任务详情

    public static final String WEEKLY_PLAN_TASK_LIST = ADMIN_TASK_MANAGEMENT + "/list/Weekly"; //获取季度计划任务列表

    public static final String GET_SUPERVISE_TASK_NUMER = ADMIN_TASK_MANAGEMENT + "-number"; //获取任务总数量

    public static final String TEST_ADD_JOB_TASK = ADMIN_TASK_MANAGEMENT + "/test/add";

    /**
     * 人事-考勤
     */
    public static final String PERSONAL_ATTENDANCE = PREFIX + "/personal/atte";

    public static final String ADD_PERSONAL_ATTE = PERSONAL_ATTENDANCE;


    public static final String GET_PERSON_PERSONAL_ATTE = PERSONAL_ATTENDANCE + "/persons";

    public static final String APPROVED_PERSONAL_ATTE = PERSONAL_ATTENDANCE + "/approved/{id}";


    public static final String LIST_PERSONAL_ATTE = PERSONAL_ATTENDANCE + "/list";

    public static final String PERSONAL_PERSONAL_ATTE = PERSONAL_ATTENDANCE + "/personal";

    public static final String PERSONAL_LIST_PERSONAL_ATTE = PERSONAL_ATTENDANCE + "/personal/{userInfoId}";

    public static final String GET_PERSONAL_ATTE = PERSONAL_ATTENDANCE + "/{id}";

    public static final String EDIT_PERSONAL_ATTE = PERSONAL_ATTENDANCE + "/{id}";


    /**
     * 党建党员信息管理
     */
    public static final String PARTY_MEMBER = PREFIX + "/party/member";

    public static final String ADD_PARTY_MEMBER = PARTY_MEMBER;

    public static final String BATCH_DEL_PARTY_MEMBER = PARTY_MEMBER;

    public static final String EDIT_PARTY_MEMBER = PARTY_MEMBER + "/{id}";

    public static final String LIST_PARTY_MEMBER = PARTY_MEMBER;

    public static final String GET_PARTY_MEMBER = PARTY_MEMBER + "/{id}";

    public static final String GET_PARTY_MEMBER_OLD = PARTY_MEMBER + "-old/{id}";

    public static final String ADD_PARTY_REWARD_PUNISHI = PREFIX + "/party/reward-punishi";

    public static final String SINGLE_PARTY_MEMBER = PARTY_MEMBER + "/single";


    /**
     * 审批任务
     */
    public static final String FLOWS = COMMON_PREFIX + "/flows";

    public static final String LIST_FLOWS = FLOWS;

    public static final String FLOWSCHECK = COMMON_PREFIX + "/flowsCheck";

    public static final String LIST_FLOWS_CHECK = FLOWSCHECK;

    public static final String GET_FLOWS = FLOWS + "/{id}/flow";


    /**
     * 财务管理--报销预审
     */
    public static final String FINANCE = PREFIX + "/finance";

    public static final String FINANCE_REIMBURSE = FINANCE + "/reimburse";

    public static final String FINANCE_REIMBURSE_LIST = FINANCE + "/reimburse-list";

    public static final String FINANCE_REIMBURSE_GET = FINANCE_REIMBURSE + "/{id}";

    /**
     * 财务管理--预算种类
     */

    public static final String FINANCE_BUDGET_CATEGORY = FINANCE + "/budget-categories";

    public static final String FINANCE_BUDGET_CATEGORY_GET = FINANCE_BUDGET_CATEGORY + "/{id}";

    /**
     * 财务管理--年度预算
     */

    public static final String FINANCE_BUDGET = FINANCE + "/budgets";

    public static final String FINANCE_BUDGET_GET = FINANCE_BUDGET + "/{budgetCategoryId}";

    public static final String FINANCE_BUDGET_EDIT = FINANCE_BUDGET + "/{id}";

    public static final String FINANCE_BUDGET_FIND_SURPLUS = FINANCE_BUDGET + "-surplus/{budgetCategoryId}";

    public static final String FINANCE_BUDGET_FIND_SUB = FINANCE_BUDGET + "-sub/{budgetCategoryId}";

    public static final String FINANCE_ANNUAL_BUDGET = FINANCE + "/annual-budget";

    public static final String FINANCE_ANNUAL_BUDGET_LIST = FINANCE + "/annual-budget-list";

    public static final String FINANCE_ANNUAL_BUDGET_GET = FINANCE + "/annual-budget/{id}";

    public static final String FINANCE_ANNUAL_BUDGET_APPROVED = FINANCE + "/annual-budget-approved/{id}";

    /**
     * 财务管理--收支明细
     */
    public static final String FINANCE_INCOME_EXP = FINANCE + "/income-exp";

    public static final String FINANCE_INCOME_EXP_FIND = FINANCE + "/income-exp-find";

    public static final String FINANCE_INCOME_EXP_GET = FINANCE + "/income-exp/{id}";

    /**
     * 权限管理
     */


    private static final String PERMISSION_PREFIX = PREFIX + "/permission";

    public static final String ADD_PERMISSION = PERMISSION_PREFIX;

    public static final String GET_PERMISSION = PERMISSION_PREFIX + "/{id}";

    public static final String EDIT_PERMISSION = PERMISSION_PREFIX + "/{id}";

    public static final String DEL_PERMISSION = PERMISSION_PREFIX + "/{id}";

    public static final String LIST_PERMISSION = PERMISSION_PREFIX;

    public static final String TREE_LIST_PERMISSION = PERMISSION_PREFIX + "/tree";

    public static final String ADD_SYSTEM_ROLE_PERMISSION = PERMISSION_PREFIX + "/system-rol-permission";

    public static final String GET_SYSTEM_ROLE_PERMISSION = PERMISSION_PREFIX + "/role/{id}";

    /**
     * 文件上传
     */
    public static final String FILE_UPLOAD = COMMON_PREFIX + "/uploadFile";

    /**
     * 党建党费信息管理
     */
    public static final String PARTY_FEE_REPORT = PREFIX + "/party/fee-report";

    public static final String ADD_PARTY_FEE = PARTY_FEE_REPORT;

    public static final String LIST_PARTY_FEE = PARTY_FEE_REPORT + "-list";

    public static final String EDIT_PARTY_FEE = PARTY_FEE_REPORT + "/{id}";

    public static final String GET_PARTY_FEE_REPORT = PARTY_FEE_REPORT + "/{id}";

    public static final String GET_PARTY_FEE_MEMBER = PARTY_FEE_REPORT + "-members";

    /**
     * 行政-档案管理
     */
    public static final String ADMIN_FILE_MANAGEMENT = ADMINISTRATION + "/file-management";

    public static final String LIST_FILE_MANAGEMENT = ADMIN_FILE_MANAGEMENT + "/list";

    public static final String DETAIL_FILE_MANAGEMENT = ADMIN_FILE_MANAGEMENT + "/{id}";

    public static final String DETAIL_FILE_MANAGEMENT_UPDATE = ADMIN_FILE_MANAGEMENT + "/update-check-time";

    public static final String GET_ADMIN_FILE_NUMBER = ADMIN_FILE_MANAGEMENT + "/number";

    public static final String EXPORT_ADMIN_FILE_NUMBER = ADMIN_FILE_MANAGEMENT + "/export";

    /**
     * 公共 用户部门
     */
    public static final String ADD_USERORG = COMMON_PREFIX + "/user-org";

    /**
     * 操作日志
     */
    public static final String SYSTEM_OPERATOIN_LOG = COMMON_PREFIX + "/operation-log"; //添加操作日志

    public static final String ADD_SYSTEM_OPERATOIN_LOG = SYSTEM_OPERATOIN_LOG; //添加操作日志

    public static final String GET_SYSTEM_OPERATOIN_LOG = SYSTEM_OPERATOIN_LOG; //查看操作日志


    public static final String ADD_SYSTEM_OPERATOIN = COMMON_PREFIX + "/operation/log"; //添加操作日志

    /**
     * 宣传素材管理
     */
    public static final String MATERIALLIBRARY = PREFIX + "/materialLibrary";

    private static final String MATERIAL_LIBRARY_MANAGEMENT_PREFIX = MATERIALLIBRARY + "/material-manage";

    public static final String ADD_MATERIAL_LIBRARY = MATERIAL_LIBRARY_MANAGEMENT_PREFIX;

    public static final String LIST_MATERIAL_LIBRARY = MATERIAL_LIBRARY_MANAGEMENT_PREFIX + "/materials";

    public static final String GET_MATERIAL_LIBRARY = MATERIAL_LIBRARY_MANAGEMENT_PREFIX + "/{id}";
}
